use Cro::HTTP::Test;
use Test;
use EyeoftheBeholder3::Routes;

test-service routes, {
    test get('/'),
            status => 200,
            body-text => '<h1> EyeoftheBeholder3 </h1>';
}

done-testing;
